@@ -35,6 +35,10 @@ $_gmsg['menu_versionmgr'] = 'Version Manager';
 $_gmsg['menu_vh'] = 'Virtual Hosts';
 $_gmsg['menu_vh_'] = 'Virtual Host';
 $_gmsg['menu_webadmin'] = 'WebAdmin Settings';
+$_gmsg['menu_devgroup'] = 'Developer Mailing List';
+$_gmsg['menu_forum'] = 'Forum';
+$_gmsg['menu_slack'] = 'Slack';
+$_gmsg['menu_cloudimage'] = 'Cloud Images';
 
 
 $_gmsg['tab_addons'] = 'Add-ons';
@@ -196,6 +200,7 @@ $_gmsg['l_compressarchive'] = 'Compress Archive';
 $_gmsg['l_compressibletypes'] = 'Compressible Types';
 $_gmsg['l_concurrentReqLimit'] = 'Concurrent Request Limit';
 $_gmsg['l_configfile'] = 'Config File';
+$_gmsg['l_congestionctrl'] = 'Congestion Control';
 $_gmsg['l_connection'] = 'Connection';
 $_gmsg['l_conntimeout'] = 'Connection Timeout (secs)';
 $_gmsg['l_contextlist'] = 'Context List';
@@ -252,7 +257,7 @@ $_gmsg['l_enableprivatecache'] = 'Enable Private Cache';
 $_gmsg['l_enablerailshosting'] = 'Enable Shared Hosting';
 $_gmsg['l_enablerewrite'] = 'Enable Rewrite';
 $_gmsg['l_enablescript'] = 'Enable Scripts/ExtApps';
-$_gmsg['l_enablespdy'] = 'Enable SPDY/HTTP2';
+$_gmsg['l_enablespdy'] = 'Enable SPDY/HTTP2/HTTP3';
 $_gmsg['l_enablestapling'] = 'Enable OCSP Stapling';
 $_gmsg['l_enablestderrlog'] = 'Enable stderr Log';
 $_gmsg['l_env'] = 'Environment';
@@ -431,6 +436,7 @@ $_gmsg['l_restrictedpermissionmask'] = 'Restricted Permission Mask';
 $_gmsg['l_restrictedscriptpermissionmask'] = 'Script Restricted Permission Mask';
 $_gmsg['l_retrytimeout'] = 'Retry Timeout (secs)';
 $_gmsg['l_retypepass'] = 'Retype Password';
+$_gmsg['l_reuseport'] = 'Enable REUSEPORT';
 $_gmsg['l_rewritebase'] = 'Rewrite Base';
 $_gmsg['l_rewritecontrol'] = 'Rewrite Control';
 $_gmsg['l_rewritedocrootrules'] = 'Document Root Rewrite Rules';
